@@ -42,6 +42,7 @@ func commentCmd(ctx *config.RunContext) *cobra.Command {
 	cmds := []*cobra.Command{commentGitHubCmd(ctx), commentGitLabCmd(ctx), commentAzureReposCmd(ctx), commentBitbucketCmd(ctx)}
 	for _, subCmd := range cmds {
 		subCmd.Flags().StringArray("policy-path", nil, "Path to Infracost policy files, glob patterns need quotes (experimental)")
+		subCmd.Flags().Bool("show-all-projects", false, "Show all projects in the table of the comment output")
 	}
 
 	cmd.AddCommand(cmds...)
@@ -64,13 +65,14 @@ func buildCommentBody(cmd *cobra.Command, ctx *config.RunContext, paths []string
 
 	combined.IsCIRun = ctx.IsCIRun()
 
+	var guardrailCheck output.GuardrailCheck
 	dryRun, _ := cmd.Flags().GetBool("dry-run")
 	if ctx.IsCloudEnabled() && !dryRun {
 		if ctx.Config.IsSelfHosted() {
 			ui.PrintWarning(cmd.ErrOrStderr(), "Infracost Cloud is part of Infracost's hosted services. Contact hello@infracost.io for help.")
 		} else {
 			combined.Metadata.InfracostCommand = "comment"
-			combined.RunID, combined.ShareURL = shareCombinedRun(ctx, combined, inputs)
+			combined.RunID, combined.ShareURL, guardrailCheck = shareCombinedRun(ctx, combined, inputs)
 		}
 	}
 
@@ -91,7 +93,9 @@ func buildCommentBody(cmd *cobra.Command, ctx *config.RunContext, paths []string
 		NoColor:           ctx.Config.NoColor,
 		ShowSkipped:       true,
 		PolicyChecks:      policyChecks,
+		GuardrailCheck:    guardrailCheck,
 	}
+	opts.ShowAllProjects, _ = cmd.Flags().GetBool("show-all-projects")
 
 	b, err := output.ToMarkdown(combined, opts, mdOpts)
 	if err != nil {
@@ -101,6 +105,9 @@ func buildCommentBody(cmd *cobra.Command, ctx *config.RunContext, paths []string
 	if policyChecks.HasFailed() {
 		return b, policyChecks.Failures
 	}
+	if len(guardrailCheck.BlockingFailures) > 0 {
+		return b, guardrailCheck.BlockingFailures
+	}
 
 	return b, nil
 }
