@@ -134,6 +134,7 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 				CurrencyFormat:    ctx.Config.CurrencyFormat,
 			}
 			opts.ShowSkipped, _ = cmd.Flags().GetBool("show-skipped")
+			opts.ShowAllProjects, _ = cmd.Flags().GetBool("show-all-projects")
 
 			validFieldsFormats := []string{"table", "html"}
 
@@ -145,7 +146,7 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 				if ctx.Config.IsSelfHosted() {
 					ui.PrintWarning(cmd.ErrOrStderr(), "Infracost Cloud is part of Infracost's hosted services. Contact hello@infracost.io for help.")
 				} else {
-					combined.RunID, combined.ShareURL = shareCombinedRun(ctx, combined, inputs)
+					combined.RunID, combined.ShareURL, _ = shareCombinedRun(ctx, combined, inputs)
 				}
 			}
 
@@ -177,6 +178,7 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 	cmd.Flags().StringP("out-file", "o", "", "Save output to a file, helpful with format flag")
 
 	cmd.Flags().String("format", "table", "Output format: json, diff, table, html, github-comment, gitlab-comment, azure-repos-comment, bitbucket-comment, bitbucket-comment-summary, slack-message")
+	cmd.Flags().Bool("show-all-projects", false, "Show all projects in the table of the comment output")
 	cmd.Flags().Bool("show-skipped", false, "List unsupported and free resources")
 	cmd.Flags().StringSlice("fields", []string{"monthlyQuantity", "unit", "monthlyCost"}, "Comma separated list of output fields: all,price,monthlyQuantity,unit,hourlyCost,monthlyCost.\nSupported by table and html output formats")
 
@@ -190,7 +192,7 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 	return cmd
 }
 
-func shareCombinedRun(ctx *config.RunContext, combined output.Root, inputs []output.ReportInput) (string, string) {
+func shareCombinedRun(ctx *config.RunContext, combined output.Root, inputs []output.ReportInput) (string, string, output.GuardrailCheck) {
 	combinedRunIds := []string{}
 	for _, input := range inputs {
 		if id := input.Root.RunID; id != "" {
@@ -205,7 +207,7 @@ func shareCombinedRun(ctx *config.RunContext, combined output.Root, inputs []out
 		log.WithError(err).Error("Failed to upload to Infracost Cloud")
 	}
 
-	return result.RunID, result.ShareURL
+	return result.RunID, result.ShareURL, result.GuardrailCheck
 }
 
 func contains(arr []string, e string) bool {
