@@ -67,6 +67,7 @@ func addRunFlags(cmd *cobra.Command) {
 	cmd.Flags().String("terraform-workspace", "", "Terraform workspace to use. Applicable when path is a Terraform directory")
 
 	cmd.Flags().StringSlice("exclude-path", nil, "Paths of directories to exclude, glob patterns need quotes")
+	cmd.Flags().Bool("include-all-paths", false, "Set project auto-detection to use all subdirectories in given path")
 
 	cmd.Flags().Bool("no-cache", false, "Don't attempt to cache Terraform plans")
 
@@ -592,19 +593,7 @@ func (r *parallelRunner) buildResources(projects []*schema.Project) {
 		projectPtrToUsageMap = r.fetchProjectUsage(projects)
 	}
 
-	for _, project := range projects {
-		usageMap := projectPtrToUsageMap[project]
-
-		for _, partial := range project.PartialResources {
-			u := usageMap[partial.ResourceData.Address]
-			project.Resources = append(project.Resources, schema.BuildResource(partial, u))
-		}
-
-		for _, partial := range project.PartialPastResources {
-			u := usageMap[partial.ResourceData.Address]
-			project.PastResources = append(project.PastResources, schema.BuildResource(partial, u))
-		}
-	}
+	schema.BuildResources(projects, projectPtrToUsageMap)
 }
 
 func (r *parallelRunner) fetchProjectUsage(projects []*schema.Project) map[*schema.Project]map[string]*schema.UsageData {
@@ -852,8 +841,7 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 		cmd.Flags().Changed("terraform-var-file") ||
 		cmd.Flags().Changed("terraform-var") ||
 		cmd.Flags().Changed("terraform-init-flags") ||
-		cmd.Flags().Changed("terraform-workspace") ||
-		cmd.Flags().Changed("terraform-use-state"))
+		cmd.Flags().Changed("terraform-workspace"))
 
 	if hasConfigFile && hasProjectFlags {
 		m := "--config-file flag cannot be used with the following flags: "
@@ -879,6 +867,7 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 		projectCfg.TerraformInitFlags, _ = cmd.Flags().GetString("terraform-init-flags")
 		projectCfg.TerraformUseState, _ = cmd.Flags().GetBool("terraform-use-state")
 		projectCfg.ExcludePaths, _ = cmd.Flags().GetStringSlice("exclude-path")
+		projectCfg.IncludeAllPaths, _ = cmd.Flags().GetBool("include-all-paths")
 
 		if cmd.Flags().Changed("terraform-workspace") {
 			projectCfg.TerraformWorkspace, _ = cmd.Flags().GetString("terraform-workspace")
@@ -900,6 +889,11 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 				p.TerraformForceCLI = true
 			}
 		}
+		if useState, _ := cmd.Flags().GetBool("terraform-use-state"); useState {
+			for _, p := range cfg.Projects {
+				p.TerraformUseState = true
+			}
+		}
 	}
 
 	cfg.NoCache, _ = cmd.Flags().GetBool("no-cache")
