@@ -12,6 +12,7 @@ import (
 
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/ext/tryfunc"
+	"github.com/hashicorp/hcl/v2/ext/typeexpr"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
 	"github.com/sirupsen/logrus"
 	yaml "github.com/zclconf/go-cty-yaml"
@@ -89,7 +90,7 @@ func NewEvaluator(
 	logger *logrus.Entry,
 ) *Evaluator {
 	ctx := NewContext(&hcl.EvalContext{
-		Functions: expFunctions(module.RootPath),
+		Functions: expFunctions(module.RootPath, logger),
 	}, nil, logger)
 
 	if visitedModules == nil {
@@ -275,7 +276,7 @@ func (e *Evaluator) evaluateModules() {
 			e.workingDir,
 			vars,
 			e.moduleMetadata,
-			e.visitedModules,
+			map[string]map[string]cty.Value{},
 			e.workspace,
 			e.blockBuilder,
 			nil,
@@ -350,19 +351,19 @@ func (e *Evaluator) expandDynamicBlock(b *Block) {
 //
 // value of:
 //
-//		test.test
-//			id: test
-//			arn: test-arn
+//	test.test
+//		id: test
+//		arn: test-arn
 //
 // that gets expanded should be:
 //
-//	   test.test
-//			a:
-//			  id: test
-//			  arn: test-arn
-//			b:
-//			  id: test
-//			  arn: test-arn
+//	test.test
+//		a:
+//		  id: test
+//		  arn: test-arn
+//		b:
+//		  id: test
+//		  arn: test-arn
 //
 // and not:
 //
@@ -375,10 +376,10 @@ func (e *Evaluator) expandDynamicBlock(b *Block) {
 //
 // which means that blocks written like:
 //
-//		resource "aws_eip" "nat_gateway" {
-//  		for_each   = test.test
+//	resource "aws_eip" "nat_gateway" {
+//		for_each   = test.test
 //			...
-//		}
+//	}
 //
 // will expand correctly to: aws_eip.nat_gateway[a], aws_eip.nat_gateway[b]. Rather than aws_eip.nat_gateway[id], aws_eip.nat_gateway[a] ...
 func (e *Evaluator) expandBlockForEaches(blocks Blocks) Blocks {
@@ -509,16 +510,25 @@ func (e *Evaluator) evaluateVariable(b *Block) (cty.Value, error) {
 		return cty.NilVal, fmt.Errorf("cannot resolve variable with no attributes")
 	}
 
-	attribute := attributes["type"]
+	attrType := attributes["type"]
 	if override, exists := e.inputVars[b.Label()]; exists {
-		return convertType(override, attribute), nil
+		return convertType(override, attrType), nil
 	}
 
 	if def, exists := attributes["default"]; exists {
-		return def.Value(), nil
+		if attrType == nil {
+			return def.Value(), nil
+		}
+
+		ty, diag := typeexpr.TypeConstraint(attrType.HCLAttr.Expr)
+		if diag.HasErrors() {
+			e.logger.WithError(diag).Debugf("error trying to convert variable %s to type %s", b.Label(), attrType.AsString())
+			return def.Value(), nil
+		}
+		return convert.Convert(def.Value(), ty)
 	}
 
-	return convertType(cty.NilVal, attribute), errorNoVarValue
+	return convertType(cty.NilVal, attrType), errorNoVarValue
 }
 
 func convertType(val cty.Value, attribute *Attribute) cty.Value {
@@ -803,7 +813,7 @@ func (e *Evaluator) loadModules(lastContext hcl.EvalContext) []*ModuleCall {
 
 // expFunctions returns the set of functions that should be used to when evaluating
 // expressions in the receiving scope.
-func expFunctions(baseDir string) map[string]function.Function {
+func expFunctions(baseDir string, logger *logrus.Entry) map[string]function.Function {
 	return map[string]function.Function{
 		"abs":              stdlib.AbsoluteFunc,
 		"abspath":          funcs.AbsPathFunc,
@@ -865,6 +875,8 @@ func expFunctions(baseDir string) map[string]function.Function {
 		"min":              stdlib.MinFunc,
 		"parseint":         stdlib.ParseIntFunc,
 		"pathexpand":       funcs.PathExpandFunc,
+		"infracostlog":     funcs.LogArgs(logger),
+		"infracostprint":   funcs.PrintArgs,
 		"pow":              stdlib.PowFunc,
 		"range":            stdlib.RangeFunc,
 		"regex":            stdlib.RegexFunc,
