@@ -12,7 +12,6 @@ import (
 	"github.com/hashicorp/hcl/v2/hclparse"
 	"github.com/sirupsen/logrus"
 	"github.com/zclconf/go-cty/cty"
-	"github.com/zclconf/go-cty/cty/gocty"
 
 	"github.com/infracost/infracost/internal/extclient"
 	"github.com/infracost/infracost/internal/hcl/modules"
@@ -166,7 +165,7 @@ func OptionWithBlockBuilder(blockBuilder BlockBuilder) Option {
 // The Parser exposes this workspace in the evaluation context under the variable named `terraform.workspace`.
 // This is commonly used by users to specify different capacity/configuration in their Terraform, e.g:
 //
-//		terraform.workspace == "prod" ? "m5.8xlarge" : "m5.4xlarge"
+//	terraform.workspace == "prod" ? "m5.8xlarge" : "m5.4xlarge"
 func OptionWithTerraformWorkspace(name string) Option {
 	name = strings.TrimSpace(name)
 	return func(p *Parser) {
@@ -209,9 +208,9 @@ type Parser struct {
 // LoadParsers inits a list of Parser with the provided option and initialPath. LoadParsers locates Terraform files
 // in the given initialPath and returns a Parser for each directory it locates a Terraform project within. If
 // the initialPath contains Terraform files at the top level parsers will be len 1.
-func LoadParsers(initialPath string, excludePaths []string, logger *logrus.Entry, options ...Option) ([]*Parser, error) {
-	pl := &projectLocator{moduleCalls: make(map[string]struct{}), excludedDirs: excludePaths, logger: logger}
-	rootPaths := pl.findRootModules(initialPath)
+func LoadParsers(initialPath string, locatorConfig *ProjectLocatorConfig, logger *logrus.Entry, options ...Option) ([]*Parser, error) {
+	pl := NewProjectLocator(logger, locatorConfig)
+	rootPaths := pl.FindRootModules(initialPath)
 	if len(rootPaths) == 0 {
 		return nil, errors.New("No valid Terraform files found at the given path, try a different directory")
 	}
@@ -535,163 +534,3 @@ func loadDirectory(logger *logrus.Entry, fullPath string, stopOnHCLError bool) (
 
 	return files, nil
 }
-
-type projectLocator struct {
-	moduleCalls  map[string]struct{}
-	excludedDirs []string
-	logger       *logrus.Entry
-}
-
-func (p *projectLocator) buildMatches(fullPath string) func(string) bool {
-	var matches []string
-	globMatches := make(map[string]struct{})
-
-	for _, dir := range p.excludedDirs {
-		var absoluteDir string
-		if dir == filepath.Base(dir) {
-			matches = append(matches, dir)
-		}
-
-		if filepath.IsAbs(dir) {
-			absoluteDir = dir
-		} else {
-			absoluteDir = filepath.Join(fullPath, dir)
-		}
-
-		globs, err := filepath.Glob(absoluteDir)
-		if err == nil {
-			for _, m := range globs {
-				globMatches[m] = struct{}{}
-			}
-		}
-	}
-
-	return func(dir string) bool {
-		if _, ok := globMatches[dir]; ok {
-			return true
-		}
-
-		base := filepath.Base(dir)
-		for _, match := range matches {
-			if match == base {
-				return true
-			}
-		}
-
-		return false
-	}
-}
-
-func (p *projectLocator) findRootModules(fullPath string) []string {
-	isSkipped := p.buildMatches(fullPath)
-	dirs := p.walkPaths(fullPath, 0)
-
-	var filtered []string
-	for _, dir := range dirs {
-		if isSkipped(dir) {
-			p.logger.Debugf("skipping directory %s as it is marked as exluded by --exclude-path", dir)
-			continue
-		}
-
-		if _, ok := p.moduleCalls[dir]; !ok {
-			filtered = append(filtered, dir)
-		}
-	}
-
-	return filtered
-}
-
-func (p *projectLocator) walkPaths(fullPath string, level int) []string {
-	p.logger.Debugf("walking path %s to discover terraform files", fullPath)
-
-	if level >= maxTfProjectSearchLevel {
-		return nil
-	}
-
-	hclParser := hclparse.NewParser()
-
-	fileInfos, err := os.ReadDir(fullPath)
-	if err != nil {
-		return nil
-	}
-
-	var dirs []string
-	for _, info := range fileInfos {
-		if info.IsDir() {
-			continue
-		}
-
-		var parseFunc func(filename string) (*hcl.File, hcl.Diagnostics)
-		if strings.HasSuffix(info.Name(), ".tf") {
-			parseFunc = hclParser.ParseHCLFile
-		}
-
-		if strings.HasSuffix(info.Name(), ".tf.json") {
-			parseFunc = hclParser.ParseJSONFile
-		}
-
-		if parseFunc == nil {
-			continue
-		}
-
-		path := filepath.Join(fullPath, info.Name())
-		_, diag := parseFunc(path)
-		if diag != nil && diag.HasErrors() {
-			p.logger.Warnf("skipping file: %s hcl parsing err: %s", path, diag.Error())
-			continue
-		}
-	}
-
-	files := hclParser.Files()
-
-	// if there are Terraform files at the top level then use this as the root module, no need to search for provider blocks.
-	if level == 0 && len(files) > 0 {
-		return []string{fullPath}
-	}
-
-	for _, file := range files {
-		body, content, diags := file.Body.PartialContent(justProviderBlocks)
-		if diags != nil && diags.HasErrors() {
-			continue
-		}
-
-		if len(body.Blocks) > 0 {
-			moduleBody, _, _ := content.PartialContent(justModuleBlocks)
-			for _, module := range moduleBody.Blocks {
-				a, _ := module.Body.JustAttributes()
-				if src, ok := a["source"]; ok {
-					val, _ := src.Expr.Value(nil)
-					if val.Type() == cty.String {
-						var realPath string
-						err := gocty.FromCtyValue(val, &realPath)
-						if err != nil {
-							p.logger.WithError(err).WithFields(logrus.Fields{
-								"module": strings.Join(module.Labels, "."),
-							}).Debug("could not read source value of module as string")
-							continue
-						}
-
-						p.moduleCalls[realPath] = struct{}{}
-					}
-				}
-			}
-
-			return []string{fullPath}
-		}
-	}
-
-	for _, info := range fileInfos {
-		if info.IsDir() {
-			if strings.HasPrefix(info.Name(), ".") {
-				continue
-			}
-
-			childDirs := p.walkPaths(filepath.Join(fullPath, info.Name()), level+1)
-			if len(childDirs) > 0 {
-				dirs = append(dirs, childDirs...)
-			}
-		}
-	}
-
-	return dirs
-}
