@@ -17,7 +17,7 @@ func PopulatePrices(ctx *config.RunContext, project *schema.Project) error {
 
 	c := apiclient.NewPricingAPIClient(ctx)
 
-	err := GetPricesConcurrent(c, resources)
+	err := GetPricesConcurrent(ctx, c, resources)
 	if err != nil {
 		return err
 	}
@@ -27,7 +27,7 @@ func PopulatePrices(ctx *config.RunContext, project *schema.Project) error {
 // GetPricesConcurrent gets the prices of all resources concurrently.
 // Concurrency level is calculated using the following formula:
 // max(min(4, numCPU * 4), 16)
-func GetPricesConcurrent(c *apiclient.PricingAPIClient, resources []*schema.Resource) error {
+func GetPricesConcurrent(ctx *config.RunContext, c *apiclient.PricingAPIClient, resources []*schema.Resource) error {
 	// Set the number of workers
 	numWorkers := 4
 	numCPU := runtime.NumCPU()
@@ -45,7 +45,7 @@ func GetPricesConcurrent(c *apiclient.PricingAPIClient, resources []*schema.Reso
 	for i := 0; i < numWorkers; i++ {
 		go func(jobs <-chan *schema.Resource, resultErrors chan<- error) {
 			for r := range jobs {
-				err := GetPrices(c, r)
+				err := GetPrices(ctx, c, r)
 				resultErrors <- err
 			}
 		}(jobs, resultErrors)
@@ -66,7 +66,7 @@ func GetPricesConcurrent(c *apiclient.PricingAPIClient, resources []*schema.Reso
 	return nil
 }
 
-func GetPrices(c *apiclient.PricingAPIClient, r *schema.Resource) error {
+func GetPrices(ctx *config.RunContext, c *apiclient.PricingAPIClient, r *schema.Resource) error {
 	if r.IsSkipped {
 		return nil
 	}
@@ -77,15 +77,21 @@ func GetPrices(c *apiclient.PricingAPIClient, r *schema.Resource) error {
 	}
 
 	for _, r := range results {
-		setCostComponentPrice(c.Currency, r.Resource, r.CostComponent, r.Result)
+		setCostComponentPrice(ctx, c.Currency, r.Resource, r.CostComponent, r.Result)
 	}
 
 	return nil
 }
 
-func setCostComponentPrice(currency string, r *schema.Resource, c *schema.CostComponent, res gjson.Result) {
+func setCostComponentPrice(ctx *config.RunContext, currency string, r *schema.Resource, c *schema.CostComponent, res gjson.Result) {
 	var p decimal.Decimal
 
+	if c.CustomPrice() != nil {
+		log.Debugf("Using user-defined custom price %v for %s %s.", *c.CustomPrice(), r.Name, c.Name)
+		c.SetPrice(*c.CustomPrice())
+		return
+	}
+
 	products := res.Get("data.products").Array()
 	if len(products) == 0 {
 		if c.IgnoreIfMissingPrice {
@@ -95,15 +101,28 @@ func setCostComponentPrice(currency string, r *schema.Resource, c *schema.CostCo
 		}
 
 		log.Warnf("No products found for %s %s, using 0.00", r.Name, c.Name)
+		setResourceWarningEvent(ctx, r, "No products found")
 		c.SetPrice(decimal.Zero)
 		return
 	}
+
 	if len(products) > 1 {
-		log.Warnf("Multiple products found for %s %s, using the first product", r.Name, c.Name)
+		log.Debugf("Multiple products found for %s %s, filtering those with prices", r.Name, c.Name)
 	}
 
-	prices := products[0].Get("prices").Array()
-	if len(prices) == 0 {
+	// Some resources may have identical records in CPAPI for the same product
+	// filters, several products are always returned and they can only be
+	// distinguished by their prices. However if we pick the first product it may not
+	// have the price due to price filter and the lookup fails. Filtering the
+	// products with prices helps to solve that.
+	productsWithPrices := []gjson.Result{}
+	for _, product := range products {
+		if len(product.Get("prices").Array()) > 0 {
+			productsWithPrices = append(productsWithPrices, product)
+		}
+	}
+
+	if len(productsWithPrices) == 0 {
 		if c.IgnoreIfMissingPrice {
 			log.Debugf("No prices found for %s %s, ignoring since IgnoreIfMissingPrice is set.", r.Name, c.Name)
 			r.RemoveCostComponent(c)
@@ -111,17 +130,27 @@ func setCostComponentPrice(currency string, r *schema.Resource, c *schema.CostCo
 		}
 
 		log.Warnf("No prices found for %s %s, using 0.00", r.Name, c.Name)
+		setResourceWarningEvent(ctx, r, "No prices found")
 		c.SetPrice(decimal.Zero)
 		return
 	}
+
+	if len(productsWithPrices) > 1 {
+		log.Warnf("Multiple products with prices found for %s %s, using the first product", r.Name, c.Name)
+		setResourceWarningEvent(ctx, r, "Multiple products found")
+	}
+
+	prices := productsWithPrices[0].Get("prices").Array()
 	if len(prices) > 1 {
 		log.Warnf("Multiple prices found for %s %s, using the first price", r.Name, c.Name)
+		setResourceWarningEvent(ctx, r, "Multiple prices found")
 	}
 
 	var err error
 	p, err = decimal.NewFromString(prices[0].Get(currency).String())
 	if err != nil {
 		log.Warnf("Error converting price to '%v' (using 0.00)  '%v': %s", currency, prices[0].Get(currency).String(), err.Error())
+		setResourceWarningEvent(ctx, r, "Error converting price")
 		c.SetPrice(decimal.Zero)
 		return
 	}
@@ -129,3 +158,19 @@ func setCostComponentPrice(currency string, r *schema.Resource, c *schema.CostCo
 	c.SetPrice(p)
 	c.SetPriceHash(prices[0].Get("priceHash").String())
 }
+
+func setResourceWarningEvent(ctx *config.RunContext, r *schema.Resource, msg string) {
+	warnings := ctx.GetResourceWarnings()
+	if warnings == nil {
+		warnings = make(map[string]map[string]int)
+		ctx.SetResourceWarnings(warnings)
+	}
+
+	resourceWarnings := warnings[r.ResourceType]
+	if resourceWarnings == nil {
+		resourceWarnings = make(map[string]int)
+		warnings[r.ResourceType] = resourceWarnings
+	}
+
+	resourceWarnings[msg] += 1
+}
