@@ -38,6 +38,27 @@ func GetDefaultRefIDFunc(d *schema.ResourceData) []string {
 	return defaultRefs
 }
 
+func DefaultCloudResourceIDFunc(d *schema.ResourceData) []string {
+	var ids []string
+
+	id := d.Get("id").String()
+	if id != "" && id != "none" && !strings.HasPrefix(id, "hcl-") {
+		ids = append(ids, id)
+	}
+
+	arnAttr, ok := arnAttributeMap[d.Type]
+	if !ok {
+		arnAttr = "arn"
+	}
+
+	arn := d.Get(arnAttr).String()
+	if strings.HasPrefix(arn, "arn:aws:") && !strings.HasPrefix(arn, "arn:aws:hcl") {
+		ids = append(ids, arn)
+	}
+
+	return ids
+}
+
 func GetSpecialContext(d *schema.ResourceData) map[string]interface{} {
 
 	specialContexts := make(map[string]interface{})
