@@ -10,7 +10,10 @@ func getComputeInstanceGroupManagerRegistryItem() *schema.RegistryItem {
 		Name:                "google_compute_instance_group_manager",
 		RFunc:               newComputeInstanceGroupManager,
 		Notes:               []string{"Multiple versions are not supported."},
-		ReferenceAttributes: []string{"version.0.instance_template"},
+		ReferenceAttributes: []string{"version.0.instance_template", "google_compute_per_instance_config.instance_group_manager"},
+		CustomRefIDFunc: func(d *schema.ResourceData) []string {
+			return []string{d.Get("name").String()}
+		},
 	}
 }
 
@@ -25,9 +28,13 @@ func newComputeInstanceGroupManager(d *schema.ResourceData, u *schema.UsageData)
 	if d.Get("target_size").Exists() {
 		targetSize = d.Get("target_size").Int()
 	}
+	if len(d.References("google_compute_per_instance_config.instance_group_manager")) > 0 {
+		targetSize += int64(len(d.References("google_compute_per_instance_config.instance_group_manager")))
+	}
 
 	var machineType string
 	purchaseOption := "on_demand"
+	scratchDisks := 0
 	disks := []*google.ComputeDisk{}
 	guestAccelerators := []*google.ComputeGuestAccelerator{}
 
@@ -39,16 +46,24 @@ func newComputeInstanceGroupManager(d *schema.ResourceData, u *schema.UsageData)
 
 		if len(instanceTemplate.Get("disk").Array()) > 0 {
 			for _, disk := range instanceTemplate.Get("disk").Array() {
-				diskSize := int64(100)
-				if size := disk.Get("disk_size_gb"); size.Exists() {
-					diskSize = size.Int()
-				}
-				diskType := disk.Get("disk_type").String()
 
-				disks = append(disks, &google.ComputeDisk{
-					Type: diskType,
-					Size: float64(diskSize),
-				})
+				diskType := disk.Get("type").String()
+				switch diskType {
+				case "SCRATCH":
+					scratchDisks++
+				default:
+					diskSize := int64(100)
+					if size := disk.Get("disk_size_gb"); size.Exists() {
+						diskSize = size.Int()
+					}
+					diskType := disk.Get("disk_type").String()
+
+					disks = append(disks, &google.ComputeDisk{
+						Type: diskType,
+						Size: float64(diskSize),
+					})
+				}
+
 			}
 		}
 
@@ -62,6 +77,7 @@ func newComputeInstanceGroupManager(d *schema.ResourceData, u *schema.UsageData)
 		PurchaseOption:    purchaseOption,
 		TargetSize:        targetSize,
 		Disks:             disks,
+		ScratchDisks:      scratchDisks,
 		GuestAccelerators: guestAccelerators,
 	}
 	r.PopulateUsage(u)
